@@ -12,9 +12,7 @@
 * 
 ******************************************************************************/
 
-#ifndef WIN32
-    #include <strings.h>
-#endif
+#include <strings.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
@@ -48,12 +46,6 @@ int bk_delete(VolInfo* volInfo, const char* pathAndName)
     bool dirFound;
     BkDir* parentDir;
     
-    if(path.numChildren == 0)
-    {
-        freePathContents(&path);
-        return BKERROR_DELETE_ROOT;
-    }
-    
     rc = makeNewPathFromString(pathAndName, &path);
     if(rc <= 0)
     {
@@ -61,6 +53,12 @@ int bk_delete(VolInfo* volInfo, const char* pathAndName)
         return rc;
     }
     
+    if(path.numChildren == 0)
+    {
+        freePathContents(&path);
+        return BKERROR_DELETE_ROOT;
+    }
+    
     /* i want the parent directory */
     path.numChildren--;
     dirFound = findDirByNewPath(&path, &(volInfo->dirTree), &parentDir);
