@@ -1,3 +1,3 @@
-off_t estimateIsoSize(const BkDir* tree, int filenameTypes);
+bk_off_t estimateIsoSize(const BkDir* tree, int filenameTypes);
 int getDirFromString(const BkDir* tree, const char* pathStr, 
                      BkDir** dirFoundPtr);
