@@ -26,6 +26,8 @@
 #define NLS_SYSTEM_AREA 16
 /* number of bytes in a logical block (in practice always 2048) */
 #define NBYTES_LOGICAL_BLOCK 2048
+/* for el torito boot images */
+#define NBYTES_VIRTUAL_SECTOR 512
 
 /*******************************************************************************
 * Joliet allows max 128 bytes
@@ -85,7 +87,7 @@ typedef struct FileToWrite
     unsigned size; /* in bytes */
     BkHardLink* location; /* basically a copy of the following variables */
     bool onImage;
-    unsigned offset; /* if on image, in bytes */
+    bk_off_t offset; /* if on image, in bytes */
     char* pathAndName; /* if on filesystem, full path + filename
                        * is to be freed by whenever the File is freed */
     BkFile* origFile; /* this pointer only has one purpose: to potentially 
