@@ -13,11 +13,7 @@
 * - most of the filename mangling code
 ******************************************************************************/
 
-#ifndef WIN32
-    #include <strings.h>
-#else
-    #define _CRT_SECURE_NO_WARNINGS 1
-#endif
+#include <strings.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -350,7 +346,6 @@ void mangleNameFor9660(const char* origName, char* newName, bool isADir)
     /* make sure base doesn't contain part of the extension */
     if(dot_p != NULL)
     {
-        /* !! test this */
         if(i > dot_p - origName)
             i = dot_p - origName;
     }
@@ -588,7 +583,6 @@ void shortenNameFor9660(const char* origName, char* newName)
     /* make sure base doesn't contain part of the extension */
     if(dot_p != NULL)
     {
-        /* !! test this to make sure it works */
         if(i > dot_p - origName)
             i = dot_p - origName;
     }
