@@ -19,15 +19,15 @@
 
 void maybeUpdateProgress(VolInfo* volInfo)
 {
-    struct timeb timeNow;
+    struct timeval timeNow;
     
     if(volInfo->progressFunction == NULL)
         return;
     
-    ftime(&timeNow);
+    gettimeofday(&timeNow, NULL);
     
-    if(timeNow.time - volInfo->lastTimeCalledProgress.time >= 1 ||
-       timeNow.millitm - volInfo->lastTimeCalledProgress.millitm >= 100)
+    if(timeNow.tv_sec - volInfo->lastTimeCalledProgress.tv_sec >= 1 ||
+       timeNow.tv_usec - volInfo->lastTimeCalledProgress.tv_usec >= 100000)
     {
         volInfo->progressFunction(volInfo);
         
