@@ -36,9 +36,6 @@
 #define VDTYPE_VOLUMEPARTITION 3
 #define VDTYPE_TERMINATOR 255
 
-/* for el torito boot images */
-#define NBYTES_VIRTUAL_SECTOR 512
-
 /* this function is really just for use in readRockridgeSymlink()
 * returns number of chars appended
 * destMaxLen doesn't include '\0'
@@ -394,8 +391,9 @@ int bk_read_vol_info(VolInfo* volInfo)
 /*******************************************************************************
 * dirDrFollows()
 * checks whether the next directory record is for a directory (not a file)
+* returns 2 if it does, and 1 if it does not
 * */
-bool dirDrFollows(VolInfo* volInfo)
+int dirDrFollows(VolInfo* volInfo)
 {
     unsigned char fileFlags;
     bk_off_t origPos;
@@ -412,9 +410,9 @@ bool dirDrFollows(VolInfo* volInfo)
     readSeekSet(volInfo, origPos, SEEK_SET);
     
     if((fileFlags >> 1 & 1) == 1)
-        return true;
+        return 2;
     else
-        return false;
+        return 1;
 }
 
 /*******************************************************************************
@@ -580,7 +578,7 @@ int readDir(VolInfo* volInfo, BkDir* dir, int filenameType,
             readSeekSet(volInfo, locExtent * NBYTES_LOGICAL_BLOCK, SEEK_SET);
             
             /* read record length */
-            readRead(volInfo, &realRootRecordLen, 1);
+            rc = readRead(volInfo, &realRootRecordLen, 1);
             if(rc != 1)
                 return BKERROR_READ_GENERIC;
             
@@ -656,7 +654,8 @@ int readDirContents(VolInfo* volInfo, BkDir* dir, unsigned size,
         {
             int recordLength;
             
-            if( dirDrFollows(volInfo) )
+            rc = dirDrFollows(volInfo);
+            if(rc == 2)
             /* directory descriptor record */
             {
                 *nextChild = malloc(sizeof(BkDir));
@@ -1114,6 +1113,9 @@ int readRockridgeSymlink(VolInfo* volInfo, BkSymLink** dest, int lenSU)
     int count;
     int count2;
     
+    if (lenSU <= 0)
+        return 1;
+    
     suFields = malloc(lenSU);
     if(suFields == NULL)
         return BKERROR_OUT_OF_MEMORY;
